#!/usr/bin/python3
import sys
import os
import hashlib
import json

md5_blocksize = 65536

def md5_of_file(filename):
  md5_hash = hashlib.md5()

  with open(filename, 'rb') as fd:
    blk = fd.read(md5_blocksize)
    while len(blk) != 0:
      md5_hash.update(blk)
      blk = fd.read(md5_blocksize)

  return md5_hash.hexdigest()




def cmd_line():
  if not  len(sys.argv) == 4:
    print("Usage:", sys.argv[0], "<input directory>", "<truth file>", "<output json>")
    return 1

  entries_dir = os.path.abspath(sys.argv[1])
  truth_file = os.path.abspath(sys.argv[2])
  output_file = sys.argv[3]

  runs = []

  for entry in os.listdir(entries_dir):
    # Grab the filename and extension
    name = os.path.basename(os.path.splitext(entry)[0])
    extension = os.path.splitext(entry)[1]

    full = os.path.join(entries_dir, entry)

    # If we can handle the extension
    if extension in [".laz", ".las"]:
      md5_hash = md5_of_file(full)
      runs.append({"contestant":name, "submission_file":full, "submission_md5":md5_hash, "submission_id":1})

  batch_contents = {}
  batch_contents["contest"] = os.path.basename(truth_file)
  batch_contents["truth_file"] = truth_file
  batch_contents["completeness_threshold"] = 0.5
  batch_contents["reg_max_shift"] = 20
  batch_contents["reg_num_steps"] = 2
  batch_contents["entries"] = runs

  with open(output_file, 'w') as outfile:
    json.dump(batch_contents, outfile, sort_keys=True, indent=4, separators=(',', ': '))

cmd_line()
